@@ -53,8 +53,8 @@ base_app::base_app(void)
 {
 	if (app != NULL)	// prevent multiple instances...
 	{
-		app->ErrorMessage("base_app ctor failed!");
-		exit(-1);
+		app->ErrorMessage("liboglappth : base_app ctor failed!");
+		exit(EXIT_FAILURE);
 	}
 	
 	app = this;
@@ -76,7 +76,7 @@ void base_app::AddCamera(ogl_camera * cam)
 	vector<ogl_camera *>::iterator it = find(camera_vector.begin(), camera_vector.end(), cam);
 	if (it != camera_vector.end())
 	{
-		cout << "duplicate cam record!" << endl;
+		cout << "liboglappth : duplicate cam record!" << endl;
 		exit(EXIT_FAILURE);
 	}
 	
@@ -224,7 +224,7 @@ void base_app::SetupLights(ogl_camera * cam)
 	{
 		if (!cam->wnd_vector[n1]->SetCurrent())
 		{
-			cout << "GL is not yet initialized -> skipping light setup!" << endl;
+			cout << "liboglappth : GL is not yet initialized -> skipping light setup!" << endl;
 			continue;
 		}
 		
@@ -314,7 +314,7 @@ void base_app::UnregisterGLNameByName(GLuint key)
 		return;
 	}
 	
-	ErrorMessage("UnregisterGLNameByName() failed!");
+	ErrorMessage("liboglappth : UnregisterGLNameByName() failed!");
 }
 
 void base_app::UnregisterGLNameByPtr(void * ptr)
@@ -333,7 +333,7 @@ void base_app::UnregisterGLNameByPtr(void * ptr)
 		else it++;
 	}
 	
-	ErrorMessage("UnregisterGLNameByPtr() failed!");
+	ErrorMessage("liboglappth : UnregisterGLNameByPtr() failed!");
 }
 
 void * base_app::FindPtrByGLName(GLuint key)
@@ -342,7 +342,7 @@ void * base_app::FindPtrByGLName(GLuint key)
 	if (it != glname_map.end()) return (* it).second;
 	else
 	{
-		ErrorMessage("FindPtrByGLName() failed!");;
+		ErrorMessage("liboglappth : FindPtrByGLName() failed!");;
 		return NULL;
 	}
 }
