@@ -26,8 +26,8 @@
 #include <GL/gl.h>
 #include <GL/glu.h>
 
-#include <cstring>	// required by gcc-4.3
-using namespace std;	// required by gcc-4.3
+#include <cstring>
+using namespace std;
 
 /*################################################################################################*/
 
@@ -53,7 +53,7 @@ base_wcl::~base_wcl(void)
 	if (wnd != NULL)
 	{
 		base_app * app = base_app::GetAppB();
-		app->ErrorMessage("base_wcl::wnd memleak!");
+		app->ErrorMessage("liboglappth : base_wcl::wnd memleak!");
 	}
 	
 	cam->UnregisterClient(this);
@@ -86,13 +86,13 @@ void base_wcl::LinkWnd(base_wnd * w)
 	if (wnd != NULL)
 	{
 		base_app * app = base_app::GetAppB();
-		app->ErrorMessage("base_wcl::LinkWnd() : wnd already in use!");
+		app->ErrorMessage("liboglappth : base_wcl::LinkWnd() : wnd already in use!");
 	}
 	
 	if (w->wcl != NULL)
 	{
 		base_app * app = base_app::GetAppB();
-		app->ErrorMessage("base_wcl::LinkWnd() : link overwrite!");
+		app->ErrorMessage("liboglappth : base_wcl::LinkWnd() : link overwrite!");
 	}
 	
 	w->wcl = this;
@@ -122,13 +122,13 @@ void base_wcl::UnlinkWnd(void)
 	if (!wnd)
 	{
 		base_app * app = base_app::GetAppB();
-		app->ErrorMessage("base_wcl::UnlinkWnd() : wnd is already NULL!");
+		app->ErrorMessage("liboglappth : base_wcl::UnlinkWnd() : wnd is already NULL!");
 	}
 	
 	if (wnd->wcl == NULL)
 	{
 		base_app * app = base_app::GetAppB();
-		app->ErrorMessage("base_wcl::UnlinkWnd() : wcl is already NULL!");
+		app->ErrorMessage("liboglappth : base_wcl::UnlinkWnd() : wcl is already NULL!");
 	}
 	
 	cam->UnregisterWnd(wnd);
@@ -146,7 +146,7 @@ void base_wcl::SetTitle(const char * t)
 {
 	if (t == NULL)
 	{
-		cout << "ERROR : base_wcl::SetTitle() got NULL." << endl;
+		cout << "liboglappth : ERROR : base_wcl::SetTitle() got NULL." << endl;
 		exit(EXIT_FAILURE);
 	}
 	
