@@ -71,19 +71,18 @@ int base_wnd::GetHeight(void)
 
 bool base_wnd::IsTimerON(void)
 {
-	cout << "base_wnd::IsTimerON() called." << endl;
+	cout << "liboglappth : base_wnd::IsTimerON() called." << endl;
 	return false;
 }
 
 void base_wnd::SetTimerON(int msec)
 {
-	cout << "base_wnd::SetTimerON() called, ";
-	cout << "msec = " << msec << "." << endl;
+	cout << "liboglappth : base_wnd::SetTimerON() called, msec = " << msec << "." << endl;
 }
 
 void base_wnd::SetTimerOFF(void)
 {
-	cout << "base_wnd::SetTimerOFF() called." << endl;
+	cout << "liboglappth : base_wnd::SetTimerOFF() called." << endl;
 }
 
 void base_wnd::SetRealized(void)
