@@ -70,12 +70,12 @@ ogl_camera::~ogl_camera(void)
 {
 	if (!obj_list.empty())
 	{
-		cout << "warning!!! ogl_camera::obj_list not empty!" << endl;
+		cout << "liboglappth : warning!!! ogl_camera::obj_list not empty!" << endl;
 	}
 	
 	if (!wnd_vector.empty())
 	{
-		cout << "error!!! ogl_camera::wnd_vector not empty!" << endl;
+		cout << "liboglappth : error!!! ogl_camera::wnd_vector not empty!" << endl;
 		exit(EXIT_FAILURE);
 	}
 }
@@ -85,7 +85,7 @@ void ogl_camera::RegisterClient(base_wcl * wcl)
 	vector<base_wcl *>::iterator it = find(wcl_vector.begin(), wcl_vector.end(), wcl);
 	if (it != wcl_vector.end())
 	{
-		cout << "duplicate wcl record!" << endl;
+		cout << "liboglappth : duplicate wcl record!" << endl;
 		exit(EXIT_FAILURE);
 	}
 	
@@ -97,7 +97,7 @@ void ogl_camera::UnregisterClient(base_wcl * wcl)
 	vector<base_wcl *>::iterator it = find(wcl_vector.begin(), wcl_vector.end(), wcl);
 	if (it == wcl_vector.end())
 	{
-		cout << "wcl record not found!" << endl;
+		cout << "liboglappth : wcl record not found!" << endl;
 		exit(EXIT_FAILURE);
 	}
 	
@@ -109,7 +109,7 @@ void ogl_camera::RegisterWnd(base_wnd * wnd)
 	vector<base_wnd *>::iterator it = find(wnd_vector.begin(), wnd_vector.end(), wnd);
 	if (it != wnd_vector.end())
 	{
-		cout << "duplicate wnd record!" << endl;
+		cout << "liboglappth : duplicate wnd record!" << endl;
 		exit(EXIT_FAILURE);
 	}
 	
@@ -121,7 +121,7 @@ void ogl_camera::UnregisterWnd(base_wnd * wnd)
 	vector<base_wnd *>::iterator it = find(wnd_vector.begin(), wnd_vector.end(), wnd);
 	if (it == wnd_vector.end())
 	{
-		cout << "wnd record not found!" << endl;
+		cout << "liboglappth : wnd record not found!" << endl;
 		exit(EXIT_FAILURE);
 	}
 	
@@ -414,7 +414,7 @@ void ogl_camera::DoCameraEvents(void)
 	list<ogl_smart_object *>::iterator so_it;
 	for (so_it = obj_list.begin();so_it != obj_list.end();so_it++)
 	{
-cout << "doing a camera_event..." << endl;
+cout << "liboglappth : doing a camera_event..." << endl;
 		(* so_it)->CameraEvent(* this);
 	}
 }
