@@ -109,7 +109,7 @@ template <class TYPE1> class oglv3d
 		}
 		else
 		{
-			cout << "problems: zero division in v3d<TYPE1>::ang !!!" << endl;
+			cout << "liboglappth : zero division in v3d<TYPE1>::ang !!!" << endl;
 			return 0.0;
 		}
 	}
@@ -126,7 +126,7 @@ template <class TYPE1> class oglv3d
 		}
 		else
 		{
-			cout << "problems: zero division in v3d<TYPE1>::tor !!!" << endl;
+			cout << "liboglappth : zero division in v3d<TYPE1>::tor !!!" << endl;
 			return 0.0;
 		}
 	}
